import IMask from "imask";
import "./assets/style.css";
import "normalize.css";
import JSConfetti from "js-confetti";
import { checkPasswordValidity, checkPasswordMatch } from "./password";
import {
  countryInput,
  zipInput,
  passwordInput,
  passwordConfirmInput,
  allInputs,
  submitBtn,
} from "./domelements";
import COUNTRY_REGEX from "./country";

const jsConfetti = new JSConfetti();

function validateForm() {
  return (
    countryInput.value.search(COUNTRY_REGEX) >= 0 &&
    checkPasswordValidity() &&
    checkPasswordMatch()
  );
}

const form = document.querySelector("#form");

IMask(zipInput, { mask: "00-000" });

function unfocusInputs() {
  allInputs.forEach((input) => {
    input.setAttribute("unfocused", 1);
  });
}

document.addEventListener("DOMContentLoaded", () => {
  form.addEventListener("submit", (event) => {
    event.preventDefault();
    if (validateForm()) {
      jsConfetti.addConfetti();
      const formData = new FormData(form);
      const formDataValue = formData.values();
      const [email, country, zip] = Array(5).fill(formDataValue.next().value);
      setTimeout(() => {
        alert(
          `Success!\nEmail: ${email}\nCountry: ${country}\nZIP: ${zip}\nPassword: [redacted]`,
        );
      }, 600);
    } else {
      alert("Hold up, one or more fields are invalid! Try again");
    }
  });

  countryInput.addEventListener("input", () => {
    const valid = countryInput.value.search(COUNTRY_REGEX) >= 0;
    countryInput.setAttribute("input-valid", valid);
    if (valid) {
      countryInput.setCustomValidity("");
    } else {
      countryInput.setCustomValidity("Invalid country");
    }
  });

  zipInput.addEventListener("input", () => {
    const valid = zipInput.value.search(/\d{2}-\d{3}/) >= 0;
    zipInput.setAttribute("input-valid", valid);
    if (valid) {
      zipInput.setCustomValidity("");
    } else {
      zipInput.setCustomValidity("ZIP Code format should be 12-345");
    }
  });

  passwordInput.addEventListener("input", checkPasswordValidity);
  passwordConfirmInput.addEventListener("input", checkPasswordValidity);

  allInputs.forEach((input) => {
    input.addEventListener("focusout", (event) => {
      event.target.setAttribute("unfocused", 1);
    });
  });
  submitBtn.addEventListener("click", unfocusInputs);

  passwordInput.addEventListener("input", () => {
    passwordInput.setAttribute("input-valid", checkPasswordValidity());
  });

  [passwordInput, passwordConfirmInput].forEach((input) =>
    input.addEventListener("input", () => {
      passwordConfirmInput.setAttribute("input-valid", checkPasswordMatch());
    }),
  );
});
